@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2016, Marvell International Ltd.
+ * Copyright (C) 2006-2017, Marvell International Ltd.
  *
  * This software file (the "File") is distributed by Marvell International
  * Ltd. under the terms of the GNU General Public License Version 2, June 1991
@@ -162,7 +162,7 @@ struct region_code_mapping {
 static const struct region_code_mapping regmap[] = {
 	{"US", 0x10}, /* US FCC */
 	{"CA", 0x20}, /* Canada */
-	{"EU", 0x30}, /* ETSI   */
+	{"FR", 0x30}, /* France */
 	{"ES", 0x31}, /* Spain  */
 	{"FR", 0x32}, /* France */
 	{"JP", 0x40}, /* Japan  */
@@ -871,21 +871,21 @@ static int mwl_probe(struct pci_dev *pdev, const struct pci_device_id *id)
 		return -ENODEV;
 
 	if (!printed_version) {
-		pr_info("<<%s version %s>>",
+		pr_info("<<%s version %s>>\n",
 			MWL_DESC, MWL_DRV_VERSION);
 		printed_version = true;
 	}
 
 	rc = pci_enable_device(pdev);
 	if (rc) {
-		pr_err("%s: cannot enable new PCI device",
+		pr_err("%s: cannot enable new PCI device\n",
 		       MWL_DRV_NAME);
 		return rc;
 	}
 
 	rc = pci_set_dma_mask(pdev, DMA_BIT_MASK(32));
 	if (rc) {
-		pr_err("%s: 32-bit PCI DMA not supported",
+		pr_err("%s: 32-bit PCI DMA not supported\n",
 		       MWL_DRV_NAME);
 		goto err_pci_disable_device;
 	}
@@ -894,7 +894,7 @@ static int mwl_probe(struct pci_dev *pdev, const struct pci_device_id *id)
 
 	hw = ieee80211_alloc_hw(sizeof(*priv), &mwl_mac80211_ops);
 	if (!hw) {
-		pr_err("%s: ieee80211 alloc failed",
+		pr_err("%s: ieee80211 alloc failed\n",
 		       MWL_DRV_NAME);
 		rc = -ENOMEM;
 		goto err_pci_disable_device;
